.. -*- coding: utf-8 -*-

===================
PyBill Dependencies
===================

PyBill depends on:

- Python 2.4 or above,

- :mod:`lxml` library in version 2.2 or above, for reading and writing XML,

- :mod:`reportlab` library in version 2.2 or above, for generating and writing 
  PDF,

- :mod:`logilab.common` library in version 0.45 or above, for reading XML 
  processing instructions.
